#!/bin/sh
echo 'name: hscolour
version: 1.20.3
id: hscolour-1.20.3-6e77e26e0faf4aef6b930f12274e936e

license: GPL
copyright: 2003-2012 Malcolm Wallace; 2006 Bjorn Bringert
maintainer: Malcolm Wallace
stability:
homepage: http://code.haskell.org/~malcolm/hscolour/
package-url:
synopsis: Colourise Haskell code.
description: hscolour is a small Haskell script to colourise Haskell code. It currently
             has six output formats:
             ANSI terminal codes (optionally XTerm-256colour codes),
             HTML 3.2 with <font> tags,
             HTML 4.01 with CSS,
             HTML 4.01 with CSS and mouseover annotations,
             XHTML 1.0 with inline CSS styling,
             LaTeX,
             and mIRC chat codes.
category: Language
author: Malcolm Wallace
pkgpath: devel/hscolour
exposed: True
exposed-modules: Language.Haskell.HsColour
                 Language.Haskell.HsColour.ANSI Language.Haskell.HsColour.Anchors
                 Language.Haskell.HsColour.ACSS Language.Haskell.HsColour.CSS
                 Language.Haskell.HsColour.Classify
                 Language.Haskell.HsColour.ColourHighlight
                 Language.Haskell.HsColour.Colourise
                 Language.Haskell.HsColour.General Language.Haskell.HsColour.HTML
                 Language.Haskell.HsColour.InlineCSS Language.Haskell.HsColour.LaTeX
                 Language.Haskell.HsColour.MIRC Language.Haskell.HsColour.Options
                 Language.Haskell.HsColour.Output Language.Haskell.HsColour.TTY
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc/hscolour-1.20.3
library-dirs: /usr/local/lib/ghc/hscolour-1.20.3
hs-libraries: HShscolour-1.20.3
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: base-4.6.0.1-d435272bc8de1d17f3a0aacfbd562dbe
         containers-0.5.0.0-3b8b869ec10d44736414ab5bea776319
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-hscolour-1.20.3/html/hscolour.haddock
haddock-html: /usr/local/share/doc/hs-hscolour-1.20.3/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
